==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/teo/v20220901/models/BillingDataFilter.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.teo.v20220901.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class BillingDataFilter extends AbstractModel{

    /**
    * 参数名称，取值范围：
zone：站点名
host：域名
proxy: 四层实例
plan: 套餐
    */
    @SerializedName("Type")
    @Expose
    private String Type;

    /**
    * 参数值
    */
    @SerializedName("Value")
    @Expose
    private String Value;

    /**
     * Get 参数名称，取值范围：
zone：站点名
host：域名
proxy: 四层实例
plan: 套餐 
     * @return Type 参数名称，取值范围：
zone：站点名
host：域名
proxy: 四层实例
plan: 套餐
     */
    public String getType() {
        return this.Type;
    }

    /**
     * Set 参数名称，取值范围：
zone：站点名
host：域名
proxy: 四层实例
plan: 套餐
     * @param Type 参数名称，取值范围：
zone：站点名
host：域名
proxy: 四层实例
plan: 套餐
     */
    public void setType(String Type) {
        this.Type = Type;
    }

    /**
     * Get 参数值 
     * @return Value 参数值
     */
    public String getValue() {
        return this.Value;
    }

    /**
     * Set 参数值
     * @param Value 参数值
     */
    public void setValue(String Value) {
        this.Value = Value;
    }

    public BillingDataFilter() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public BillingDataFilter(BillingDataFilter source) {
        if (source.Type != null) {
            this.Type = new String(source.Type);
        }
        if (source.Value != null) {
            this.Value = new String(source.Value);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Type", this.Type);
        this.setParamSimple(map, prefix + "Value", this.Value);

    }
}

==> tencentcloud-sdk-java-3.1.1130-sources.jar: com/tencentcloudapi/teo/v20220901/models/BillingDataFilter.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.teo.v20220901.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class BillingDataFilter extends AbstractModel {

    /**
    * 参数名称。
    */
    @SerializedName("Type")
    @Expose
    private String Type;

    /**
    * 参数值。
    */
    @SerializedName("Value")
    @Expose
    private String Value;

    /**
     * Get 参数名称。 
     * @return Type 参数名称。
     */
    public String getType() {
        return this.Type;
    }

    /**
     * Set 参数名称。
     * @param Type 参数名称。
     */
    public void setType(String Type) {
        this.Type = Type;
    }

    /**
     * Get 参数值。 
     * @return Value 参数值。
     */
    public String getValue() {
        return this.Value;
    }

    /**
     * Set 参数值。
     * @param Value 参数值。
     */
    public void setValue(String Value) {
        this.Value = Value;
    }

    public BillingDataFilter() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public BillingDataFilter(BillingDataFilter source) {
        if (source.Type != null) {
            this.Type = new String(source.Type);
        }
        if (source.Value != null) {
            this.Value = new String(source.Value);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Type", this.Type);
        this.setParamSimple(map, prefix + "Value", this.Value);

    }
}
